@@ -2,6 +2,8 @@
 The abi3info APIs.
 """
 
+from __future__ import annotations
+
 from typing import Final
 
 from abi3info._internal import (
@@ -22,7 +24,7 @@ from abi3info.models import (
     Typedef,
 )
 
-__version__ = "2022.12.06-2"
+__version__ = "2023.02.08"
 """
 The current version of abi3info.
 """
